#!/bin/bash

NAME="newcorpus"
TOOLDIR="."
NGRAM="2"

while getopts "p:d:n:?" opt; do
		case "$opt" in
		\?) echo "Usage : $0 [OPTIONS]"
				echo "Build a language model from a text corpus with LMTools"
				echo "    Options : -p fileprefix"
				echo "    Options : -d \"lmtools/directory/path\""
				echo "    Options : -n n-gram level (1 or more)"
				exit 0
				;;
		p)  NAME=${OPTARG}  ;;
		d)  TOOLDIR=${OPTARG}  ;;
		n)  NGRAM=${OPTARG}  ;;
		esac
done

# Create ccs file
echo "<s>" > $NAME.ccs

# Compute the word unigram counts
(cat $NAME.txt ; echo "<s>" ; echo "</s>") | $TOOLDIR/text2wfreq > $NAME.wfreq

# Convert the word unigram counts into a vocabulary consisting of the 20,000 most common words
cat $NAME.wfreq | $TOOLDIR/wfreq2vocab -top 20000 > $NAME.vocab

# Generate a binary id n-gram of the training text, based on this vocabulary
cat $NAME.txt | $TOOLDIR/text2idngram -n $NGRAM -vocab $NAME.vocab -buffer 100 -temp ~/tmp/ > $NAME.idngram

# Convert the idngram into an arpa format language model
# Output format : -arpa $NAME.lm or -binary $NAME.binlm
# The discounting strategy and its parameters are specified by the -linear, -absolute, -good_turing and -witten_bell options.
$TOOLDIR/idngram2lm -idngram $NAME.idngram -vocab $NAME.vocab -n $NGRAM -arpa $NAME.lm -witten_bell -context $NAME.ccs

# Delete temporary files
rm -f $NAME.ccs $NAME.wfreq $NAME.vocab $NAME.idngram
