# ---------------------------------------------------------------
# Additionnal make commands for .pro files
# Bruno ANSELME - <be.root@free.fr>
# Add make targets : translation, files, version, count and doc
# ---------------------------------------------------------------
unix {
  QMAKE_DATE  = $$system_quote($$system(date +"%F\\ %X"))
  ALLFILES    = "$${RESOURCES} $${FORMS} $${SOURCES} $${HEADERS} $${TRANSLATIONS} $${OTHER_FILES}"
  NL          = $$escape_expand(\\n\\t)

  # --- make translation ---
  translation.target = translation
  translation.depends = .
  translation.commands = \
    lupdate $${TARGET}.pro -no-obsolete 2>/dev/null ; \
    linguist $${TARGET}_fr.ts  ; \
    lrelease $${TARGET}.pro
  QMAKE_EXTRA_TARGETS += translation

  # --- make files ---
  files.target = files
  files.depends = .
  files.commands = @ls -1R $${ALLFILES}
  QMAKE_EXTRA_TARGETS += files

  # --- make version ---
  version.target = version
  version.depends = $${TARGET}.pro
  version.commands = \
    sed -i s/Version:\\ .*/Version:\\ $${VERSION}/ $${TARGET}.dsc ; \
    sed -i s/Version:\\ .*/Version:\\ $${VERSION}/ $${TARGET}.spec ; \
    sed -i s/$${TARGET}-.*\\.tar\\.gz/$${TARNAME}\.tar\.gz/ $${TARGET}.dsc ; \
    sed -i s/define\\ APP_MAJOR\\ .*/define\\ APP_MAJOR\\ \\ \\ \\ \\ $${MAJOR}/ app_version.h ; \
    sed -i s/define\\ APP_MINOR\\ .*/define\\ APP_MINOR\\ \\ \\ \\ \\ $${MINOR}/ app_version.h ; \
    sed -i s/define\\ APP_RELEASE\\ .*/define\\ APP_RELEASE\\ \\ \\ $${RELEASE}/ app_version.h ; \
    sed -i s/define\\ APP_BUILD\\ .*/define\\ APP_BUILD\\ \\ \\ \\ \\ \\\"$${QMAKE_DATE}\\\"/ app_version.h ; \
    sed -i s/define\\ APP_VERSION\\ .*/define\\ APP_VERSION\\ \\ \\ \\\"$${VERSION}\\\"/ app_version.h
  QMAKE_EXTRA_TARGETS += version

  # --- make count ---
  countlines.target = count
  countlines.depends = clean
  countlines.commands = \
    @echo "Nombre de lignes de code : " ; wc -l *.h *.cpp
  QMAKE_EXTRA_TARGETS += countlines

  # --- make doc ---
  doc.target = doc
  doc.depends = clean
  doc.commands = \
    rm -fv html/ ; \
    doxygen Doxyfile
  QMAKE_EXTRA_TARGETS += doc

  # --- make help ---
  help.target = help
  help.depends = .
  help.commands = \
    @echo -e "Additionnal make targets:\\\n" \
     " files\\\t\\\t\\\t: List all files to archive\\\n" \
     " count\\\t\\\t\\\t: Count code lines\\\n" \
     " version\\\t\\\t: Update version number and build date\\\n" \
     " doc\\\t\\\t\\\t: Run doxywizard to build html documentation\\\n"

}
