#-------------------------------------------------
# Project created by QtCreator 2019-02-05T13:30:12
# Voice command for Linux/X.org
# 2019-2020 Bruno ANSELME <be.root@free.fr>
# To update it for Wayland, look in file guicontrol.cpp
# Bruno ANSELME - Feb/Mar/Apr 2019
#               - Nov/Dec 2019
#               - Jan/Feb/Mar 2020
#-------------------------------------------------

BASEDIR      = cmusphinx                            # Base dir for librairies compilation

QT       += core gui
greaterThan(QT_MAJOR_VERSION, 4): QT += widgets

TARGET      = nocomprendo
TEMPLATE    = app
MAJOR       = 1
MINOR       = 2
RELEASE     = 0
VERSION     = $${MAJOR}.$${MINOR}.$${RELEASE}

CONFIG  += c++11
CONFIG  += use_espeak                               # Comment this line if espeak is not available on the target computer

QMAKE_CXXFLAGS += -Wno-unused-result

DEFINES += QT_DEPRECATED_WARNINGS
DEFINES += QT_DISABLE_DEPRECATED_BEFORE=0x060000    # Disables all the APIs deprecated before Qt 6.0.0

INCLUDEPATH +=  \
    $$BASEDIR/include \
    $$BASEDIR/include/sphinxbase \
    $$BASEDIR/include/pocketsphinx

LIBS +=  $$PWD/libpocketsphinx.a $$PWD/libsphinxbase.a $$PWD/libsphinxad.a
LIBS += -lpulse -lpulse-simple -lm -lutil -lxdo

use_espeak {
    DEFINES += ENABLE_ESPEAK
    LIBS +=  -lespeak -lpthread
}

PRE_TARGETDEPS += libpocketsphinx.a libsphinxbase.a

SOURCES   += \
    aboutdialog.cpp \
    command.cpp \
    commandset.cpp \
    comprendo.cpp \
    editcommand.cpp \
    editset.cpp \
    editvocabulary.cpp \
    fileviewer.cpp \
    guicontrol.cpp \
    langchooser.cpp \
    languagemodeler.cpp \
    listener.cpp \
    main.cpp \
    mainwindow.cpp \
    misc.cpp \
    mouseblink.cpp \
    osd.cpp \
    osdeditor.cpp \
    reminder.cpp \
    selectset.cpp \
    settings.cpp \
    speak.cpp \
    trayicon.cpp \
    utterancebuilder.cpp \
    zoombutton.cpp \

HEADERS  += \
    aboutdialog.h \
    app_version.h \
    command.h \
    commandset.h \
    comprendo.h \
    editcommand.h \
    editset.h \
    editvocabulary.h \
    fileviewer.h \
    guicontrol.h \
    langchooser.h \
    languagemodeler.h \
    listener.h \
    mainwindow.h \
    misc.h \
    mouseblink.h \
    osd.h \
    osdeditor.h \
    params.h \
    reminder.h \
    selectset.h \
    settings.h \
    speak.h \
    trayicon.h \
    utterancebuilder.h \
    zoombutton.h

FORMS    +=  \
    about.ui \
    editcommand.ui \
    editset.ui \
    editvocabulary.ui \
    fileview.ui \
    langchooser.ui \
    mainwindow.ui \
    osd.ui \
    setselector.ui \
    settings.ui \
    utterancebuilder.ui

RESOURCES += nc.qrc

TRANSLATIONS = $${TARGET}_fr.ts

DISTFILES +=

OTHER_FILES += \
    icons* \
    langs* \
    help*  \
    lmtools* \
    packages* \
    changelog.* \
    Doxyfile \                       # For doxygen
    $${TARGET}.spec  rpmlintrc \            # rpm packages configuration files
    debian.* $${TARGET}.dsc \               # debian packages configuration files
    $${TARGET}.desktop $${TARGET}.png \
    *.qm   \                                # Translations
    license-gpl-3.0.* \                     # License
    readme-*.txt \
    $${TARGET}.pro *.pri                    # QtCreator project

target.path     = /usr/bin                  # Application installation dir

APP_PATH        = /usr/share/$${TARGET}
USER_PATH       = $(HOME)/.config/$${TARGET}

POCKET_PATH     = $${APP_PATH}/pocketsphinx
ACOUSTIC_DIR    = pocketsphinx

tools.path      = $${APP_PATH}
tools.files     = lmtools/*.dict lmtools/DICTS.LICENSE
#tools.files     = lmtools/*                # Until version 1.0.13

pocket.depends  = install_tools
pocket.path     = $${POCKET_PATH}
pocket.files    = $${ACOUSTIC_DIR}/*

userdata.path   = $${APP_PATH}/defsets
userdata.files  = langs/*

icons.path      = /usr/share/icons
icons.files     = $${TARGET}*.png

desktop.path    = /usr/share/applications
desktop.files   = $${TARGET}.desktop

INSTALLS += tools pocket userdata target icons desktop

# More make targets
include(more-make-targets.pri)              # Additional targets : version, translation, files, count
include(psphinx-make-targets.pri)           # PocketSphinx additional targets for static libraries. Build from sources.
QMAKE_EXTRA_TARGETS += help                 # Each .pri file add help lines. Register help target when finished now.

### References ###
# Xdotool         : https://www.semicomplete.com/projects/xdotool/
# Keysyms         : http://wiki.linuxquestions.org/wiki/List_of_keysyms
# Espeak          : http://espeak.sourceforge.net/
# Pocketsphinx    : https://cmusphinx.github.io
# Dictionaries    : https://sourceforge.net/projects/cmusphinx/files/Acoustic%20and%20Language%20Models/
# SimpleLM perl   : http://www.speech.cs.cmu.edu/tools/download/quick_lm.pl
# SimpleLM online : http://www.speech.cs.cmu.edu/tools/lm.html
# CMU toolkit     : http://www.speech.cs.cmu.edu/SLM/toolkit.html             (version 2, command line tool)
# CMU online tool : http://www.speech.cs.cmu.edu/tools/lmtool-new.html        (version 3, not found as command line tool)

# Todo
