# ---------------------------------------------------------------
# Additionnal make commands for nocomprendo
# Bruno ANSELME - <be.root@free.fr>
# Sphinxbase and PocketSphinx build, copy libraries and includes for static link.
# Add make targets : sphinxbase, pocketsphinx, cleansphinx and cleanall
# ---------------------------------------------------------------
unix {
  PACKAGESDIR       = packages
  SPHINX_TARBALL    = sphinxbase-5prealpha.tar.gz
  SPHINX_DIR        = sphinxbase-5prealpha
  POCKET_TARBALL    = pocketsphinx-5prealpha-nc.tar.gz
  POCKET_DIR        = pocketsphinx-5prealpha
  TOOLKIT_TARBALL   = CMU-Cam_Toolkit_v2.tar.gz
  TOOLKIT_DIR       = CMU-Cam_Toolkit_v2
  INSTALL_DIR       = $$PWD/$$BASEDIR

  FRENCH_TARBALL    = cmusphinx-fr-ptm-5.2.tar.gz
  FRENCH_DIR        = cmusphinx-fr-ptm-5.2
  ENGLISH_TARBALL   = cmusphinx-en-us-ptm-5.2.tar.gz
  ENGLISH_DIR       = cmusphinx-en-us-ptm-5.2

  # --- make sphinxbase ---
  sphinxbase.target    = libsphinxbase.a
  sphinxbase.depends  =
  sphinxbase.commands = \
    mkdir -p $${BASEDIR} ; \
    cp $${PACKAGESDIR}/$${SPHINX_TARBALL} $${BASEDIR} ; \
    cd $${BASEDIR}  ; \
    tar zxvf $${SPHINX_TARBALL}  ; \
    cd $${SPHINX_DIR} ; \
    ./autogen.sh --without-python --prefix=$${INSTALL_DIR} && \
    make && \
    make install ; \
    cd .. ; cp include/sphinxbase/sphinx_config.h include/ $${NL}\        # Copy include files for sphinxbase
    cp $${BASEDIR}/lib/libsphinx*.a  .
  QMAKE_EXTRA_TARGETS += sphinxbase

  # --- make pocketsphinx and copy acoustic models---
  pocketsphinx.target = libpocketsphinx.a
  pocketsphinx.depends = sphinxbase
  pocketsphinx.commands = \
    mkdir -p $${BASEDIR} ; \
    cp $${PACKAGESDIR}/$${POCKET_TARBALL} $${BASEDIR} ; \
    cd $${BASEDIR}  ; \
    tar zxvf $${POCKET_TARBALL}  ; \
    cd $${POCKET_DIR} ; \
    ./autogen.sh --without-python --prefix=$${INSTALL_DIR} &&  \
    make && \
    make install && \
    cd .. ; cp include/pocketsphinx/pocketsphinx.h include/ $${NL}\
    cp $${BASEDIR}/lib/libpocket*.a  . ; \
    # Copy acoustic models
    mkdir $${ACOUSTIC_DIR} ; \
    tar zxvf $${PACKAGESDIR}/$${FRENCH_TARBALL} ; \
    mv $${FRENCH_DIR} $${ACOUSTIC_DIR}/fr_FR ; \
    tar zxvf $${PACKAGESDIR}/$${ENGLISH_TARBALL} ; \
    mv $${ENGLISH_DIR} $${ACOUSTIC_DIR}/en_US
  QMAKE_EXTRA_TARGETS += pocketsphinx

  # --- make cleansphinx ---
  cleansphinx.target = cleansphinx
  cleansphinx.depends = .
  cleansphinx.commands = \
    cd $${BASEDIR}  ; \
    rm -Rf $${SPHINX_DIR} $${POCKET_DIR} bin/ lib/ lib64/ share/ $${SPHINX_TARBALL} $${POCKET_TARBALL}
  QMAKE_EXTRA_TARGETS += cleansphinx

  # --- make cleanall ---
  # Clean libs, includes, lmtools and acoustics models. Will trigger a full rebuild
  cleanall.target = cleanall
  cleanall.depends = clean cleansphinx
  cleanall.commands = \
    rm -Rfv *.a $${BASEDIR}/include/ ; \
    rm -Rfv $${ACOUSTIC_DIR}
  QMAKE_EXTRA_TARGETS += cleanall

  # --- Add depends to main and clean targets
  $${TARGET}.depends  += libpocketsphinx.a libsphinxbase.a
  QMAKE_EXTRA_TARGETS += $${TARGET}

  # --- make help ---
  help.commands += \
     " libsphinxbase.a\\\t: Build libsphinxbase.a and libsphinxad.a, copy libs and includes\\\n" \
     " libpocketsphinx.a\\\t: Build pocketsphinx.a, copy lib and includes\\\n" \
     " cleansphinx\\\t\\\t: Delete sphinx and pocketsphinx building tree, keeping libraries and includes\\\n" \
     " cleanall\\\t\\\t: Delete libraries and includes needed for $${TARGET}. Will trigger a full build on next make\\\n"

}
